================================
``psyclone.psyir.nodes.routine``
================================

.. automodule:: psyclone.psyir.nodes.routine

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.routine


Classes
=======

- :py:class:`Routine`:
  A sub-class of a Schedule that represents a subroutine, function or


.. autoclass:: Routine
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Routine
      :parts: 1
